@@ -84,15 +84,15 @@
     </message>
     <message>
         <location filename="../batterywatchersettings.cpp" line="44"/>
-        <source>Battery with percentage</source>
+        <source>Battery with percentage and background</source>
         <comment>icons</comment>
-        <translation>Yüzdeli Pil</translation>
+        <translation>Yüzdesi ve arka planı olan pil</translation>
     </message>
     <message>
         <location filename="../batterywatchersettings.cpp" line="45"/>
-        <source>Battery with percentage, opaque</source>
+        <source>Battery with percentage</source>
         <comment>icons</comment>
-        <translation>Yüzdeli mat pil</translation>
+        <translation>Yüzdeli Pil</translation>
     </message>
     <message>
         <location filename="../batterywatchersettings.cpp" line="104"/>
