@@ -5,8 +5,8 @@
     <name>BatteryHelper</name>
     <message>
         <location filename="../batteryhelper.cpp" line="44"/>
-        <source>Empty</source>
-        <translation>Tyhjä</translation>
+        <source>Stable</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="46"/>
@@ -110,7 +110,7 @@
     </message>
     <message numerus="yes">
         <location filename="../batteryhelper.cpp" line="111"/>
-        <source>%n hour(s)</source>
+        <source>%Ln hour(s)</source>
         <translation type="unfinished">
             <numerusform></numerusform>
             <numerusform></numerusform>
@@ -118,7 +118,7 @@
     </message>
     <message numerus="yes">
         <location filename="../batteryhelper.cpp" line="112"/>
-        <source>%n minute(s)</source>
+        <source>%Ln minute(s)</source>
         <translation type="unfinished">
             <numerusform></numerusform>
             <numerusform></numerusform>
@@ -127,12 +127,12 @@
     <message>
         <location filename="../batteryhelper.cpp" line="117"/>
         <source>remaining %1</source>
-        <translation type="unfinished"></translation>
+        <translation>jäljellä %1</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="122"/>
         <source>to full %1</source>
-        <translation type="unfinished"></translation>
+        <translation>täyteen %1</translation>
     </message>
 </context>
 <context>
@@ -188,7 +188,7 @@
     <message>
         <location filename="../batteryinfoframe.ui" line="141"/>
         <source>Energy rate:</source>
-        <translation>Lataus aste:</translation>
+        <translation>Latausaste:</translation>
     </message>
     <message>
         <location filename="../batteryinfoframe.ui" line="165"/>
@@ -205,6 +205,11 @@
         <source>Vendor:</source>
         <translation>Valmistaja:</translation>
     </message>
+    <message>
+        <location filename="../batteryinfoframe.cpp" line="65"/>
+        <source>Empty</source>
+        <translation type="unfinished">Tyhjä</translation>
+    </message>
 </context>
 <context>
     <name>BatteryWatcher</name>
@@ -225,26 +230,26 @@
     </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="131"/>
-        <source>Suspending in %n second(s)</source>
-        <translation>
-            <numerusform>Siirtyy lepotilaa % sekunnin kuluttua</numerusform>
-            <numerusform>Siirtyy lepotilaan % sekunnin kuluttua</numerusform>
+        <source>Suspending in %Ln second(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="134"/>
-        <source>Hibernating in %n second(s)</source>
-        <translation>
-            <numerusform>Siirtyy horrostilaan sekunnin kuluttua</numerusform>
-            <numerusform>Siirtyy horrostilaan % sekunnin kuluttua</numerusform>
+        <source>Hibernating in %Ln second(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="137"/>
-        <source>Shutting down in %n second(s)</source>
-        <translation>
-            <numerusform>Sammutetaan sekunnin kuluttua</numerusform>
-            <numerusform>Sammutetaan % sekunnin kuluttua</numerusform>
+        <source>Shutting down in %Ln second(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
         </translation>
     </message>
 </context>
@@ -277,7 +282,7 @@
         <location filename="../powermanagementd.cpp" line="116"/>
         <source>You are running LXQt Power Management for the first time.
 You can configure it from settings... </source>
-        <translation>Käytät LXQt Virranhallintaa ensimmäistä kertaa.
+        <translation>Käytät LXQt:n virranhallintaa ensimmäistä kertaa.
 Voit muuttaa sen toimintaa asetuksista… </translation>
     </message>
     <message>
@@ -325,7 +330,7 @@ Voit muuttaa sen toimintaa asetuksista… </translation>
     </message>
     <message>
         <location filename="../trayicon.cpp" line="101"/>
-        <location filename="../trayicon.cpp" line="191"/>
+        <location filename="../trayicon.cpp" line="193"/>
         <source>About</source>
         <translation>Tietoja</translation>
     </message>
@@ -335,22 +340,27 @@ Voit muuttaa sen toimintaa asetuksista… </translation>
         <translation>Poista kuvake käytöstä</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="192"/>
+        <location filename="../trayicon.cpp" line="162"/>
+        <source>Empty</source>
+        <translation type="unfinished">Tyhjä</translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="194"/>
         <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
-        <translation>&lt;p&gt;  &lt;b&gt;LXQt Virranhallinta&lt;/b&gt;&lt;br/&gt;  - Virranhallinta LXQt Työpöytäympäristölle&lt;/p&gt;&lt;p&gt; Tekijät:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - ja muita Razor- ja LXQt-projekteista&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</translation>
+        <translation>&lt;p&gt;  &lt;b&gt;LXQt:n virranhallinta&lt;/b&gt;&lt;br/&gt;  - Virranhallinta LXQt-työpöytäympäristölle&lt;/p&gt;&lt;p&gt; Tekijät:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - ja muita Razor- ja LXQt-projekteista&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="210"/>
+        <location filename="../trayicon.cpp" line="212"/>
         <source>LXQt Power Management info</source>
-        <translation>LXQt Virranhallinta info</translation>
-    </message>
-    <message>
-        <location filename="../trayicon.cpp" line="211"/>
-        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
-        <translation>LXQt Virranhallinnan tehtäväpalkin kuvake voidaan ottaa käyttöön ohjelmassa &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
+        <translation>LXQt:n virranhallinnan tiedot</translation>
     </message>
     <message>
         <location filename="../trayicon.cpp" line="213"/>
+        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
+        <translation>LXQt:n virranhallinnan tehtäväpalkin kuvake voidaan ottaa käyttöön ohjelmassa &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="215"/>
         <source>Configure now</source>
         <translation>Muuta asetuksia nyt</translation>
     </message>
